#[non_exhaustive]pub enum AuthorizationCodeErrorResponseType {
InvalidRequest,
UnauthorizedClient,
AccessDenied,
UnsupportedResponseType,
InvalidScope,
ServerError,
TemporarilyUnavailable,
}Expand description
Error response returned by server after requesting an authorization code.
The fields in this structure are defined in Section 4.1.2.1 of RFC 6749.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidRequest
The request is invalid.
It is missing a required parameter, includes an invalid parameter value, includes a parameter more than once, or is otherwise malformed.
The client is not authorized to request an authorization code using this method.
AccessDenied
The resource owner or authorization server denied the request.
UnsupportedResponseType
The authorization server does not support obtaining an authorization code using this method.
InvalidScope
The requested scope is invalid, unknown, or malformed.
ServerError
The authorization server encountered an unexpected error.
The authorization server is currently unable to handle the request due to a temporary overloading or maintenance of the server.
Implementations