#[non_exhaustive]pub enum ClientRegistrationErrorResponseType {
InvalidRedirectUri,
InvalidClientMetadata,
InvalidSoftwareStatement,
UnapprovedSoftwareStatement,
}Expand description
Error response returned by server after requesting an authorization code.
The variant of this enum are defined in Section 3.2.2 of RFC 7591.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidRedirectUri
The value of one or more redirection URIs is invalid.
InvalidClientMetadata
The value of one of the client metadata fields is invalid and the server has rejected this request.
InvalidSoftwareStatement
The software statement presented is invalid.
UnapprovedSoftwareStatement
The software statement presented is not approved for use by this authorization server.
Implementations