pub enum RevocationErrorResponseType {
UnsupportedTokenType,
Basic(BasicErrorResponseType),
}Expand description
OAuth 2.0 Token Revocation error response types.
These error types are defined in Section 2.2.1 of RFC 7009 and Section 5.2 of RFC 6749
Variants
UnsupportedTokenType
The authorization server does not support the revocation of the presented token type.
Basic(BasicErrorResponseType)
The authorization server responded with some other error as defined RFC 6749 error.