pub type OAuthRequestError<T> = RequestTokenError<HttpClientError<Error>, StandardErrorResponse<T>>;Expand description
An error when interacting with the OAuth 2.0 authorization server.
Aliased Type
pub enum OAuthRequestError<T> {
ServerResponse(StandardErrorResponse<T>),
Request(HttpClientError<Error>),
Parse(Error<Error>, Vec<u8>),
Other(String),
}Variants
ServerResponse(StandardErrorResponse<T>)
Error response returned by authorization server. Contains the parsed ErrorResponse
returned by the server.
Request(HttpClientError<Error>)
An error occurred while sending the request or receiving the response (e.g., network connectivity failed).
Parse(Error<Error>, Vec<u8>)
Failed to parse server response. Parse errors may occur while parsing either successful or error responses.
Other(String)
Some other type of error occurred (e.g., an unexpected server response).